==> zio-aws-directconnect_2.12-5.17.155.2-sources.jar: zio/aws/directconnect/model/UpdateDirectConnectGatewayAssociationResponse.scala <==
package zio.aws.directconnect.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateDirectConnectGatewayAssociationResponse(
    directConnectGatewayAssociation: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.directconnect.model.UpdateDirectConnectGatewayAssociationResponse = {
    import UpdateDirectConnectGatewayAssociationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.directconnect.model.UpdateDirectConnectGatewayAssociationResponse
      .builder()
      .optionallyWith(
        directConnectGatewayAssociation.map(value => value.buildAwsValue())
      )(_.directConnectGatewayAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse.ReadOnly =
    zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse
      .wrap(buildAwsValue())
}
object UpdateDirectConnectGatewayAssociationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.directconnect.model.UpdateDirectConnectGatewayAssociationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse =
      zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse(
        directConnectGatewayAssociation.map(value => value.asEditable)
      )
    def directConnectGatewayAssociation: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ]
    def getDirectConnectGatewayAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "directConnectGatewayAssociation",
      directConnectGatewayAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.directconnect.model.UpdateDirectConnectGatewayAssociationResponse
  ) extends zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse.ReadOnly {
    override val directConnectGatewayAssociation: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = scala
      .Option(impl.directConnectGatewayAssociation())
      .map(value =>
        zio.aws.directconnect.model.DirectConnectGatewayAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.directconnect.model.UpdateDirectConnectGatewayAssociationResponse
  ): zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-directconnect_2.12-5.17.267.6-sources.jar: zio/aws/directconnect/model/UpdateDirectConnectGatewayAssociationResponse.scala <==
package zio.aws.directconnect.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateDirectConnectGatewayAssociationResponse(
    directConnectGatewayAssociation: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.directconnect.model.UpdateDirectConnectGatewayAssociationResponse = {
    import UpdateDirectConnectGatewayAssociationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.directconnect.model.UpdateDirectConnectGatewayAssociationResponse
      .builder()
      .optionallyWith(
        directConnectGatewayAssociation.map(value => value.buildAwsValue())
      )(_.directConnectGatewayAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse.ReadOnly =
    zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse
      .wrap(buildAwsValue())
}
object UpdateDirectConnectGatewayAssociationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.directconnect.model.UpdateDirectConnectGatewayAssociationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse =
      zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse(
        directConnectGatewayAssociation.map(value => value.asEditable)
      )
    def directConnectGatewayAssociation: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ]
    def getDirectConnectGatewayAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "directConnectGatewayAssociation",
      directConnectGatewayAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.directconnect.model.UpdateDirectConnectGatewayAssociationResponse
  ) extends zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse.ReadOnly {
    override val directConnectGatewayAssociation: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.directConnectGatewayAssociation())
      .map(value =>
        zio.aws.directconnect.model.DirectConnectGatewayAssociation.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.directconnect.model.UpdateDirectConnectGatewayAssociationResponse
  ): zio.aws.directconnect.model.UpdateDirectConnectGatewayAssociationResponse.ReadOnly =
    new Wrapper(impl)
}
